<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://themeatelier.net
 * @since      1.0.0
 *
 * @package    Event_Detailer_Pro
 * @subpackage Event_Detailer_Pro/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Event_Detailer_Pro
 * @subpackage Event_Detailer_Pro/admin
 * @author     ThemeAtelier <themeatelierbd@gmail.com>
 */
class Event_Detailer_Pro_Admin
{

	protected $suffix;
	private $plugin_name;
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{
		$this->suffix      = defined('SCRIPT_DEBUG') && SCRIPT_DEBUG || defined('WP_DEBUG') && WP_DEBUG ? '' : '.min';
		$this->plugin_name = $plugin_name;
		$this->version = $version;

		// Autoload system.
		spl_autoload_register(array($this, 'autoload'));
		EDP_Metaboxes::layout_metabox('ta_edp_layouts');
		EDP_Metaboxes::option_metabox('ta_edp_view_options');
		EDP_Settings::settings('ta_edp_settings');

		$active_plugins = get_option('active_plugins');
		foreach ($active_plugins as $active_plugin) {
			$_temp = strpos($active_plugin, 'event-detailer-pro.php');
			if (false != $_temp) {
				add_filter('plugin_action_links_' . $active_plugin, array($this, 'add_plugin_action_links'));
			}
		}
	}

	public function add_plugin_action_links($links)
	{
		$new_links = array(
			sprintf('<a href="%s">%s</a>', admin_url('post-new.php?post_type=event_detailer'), esc_html__('Create Event Template', 'event-detailer-pro')),
		);
		return array_merge($new_links, $links);
	}

	/**
	 * Autoload class files on demand
	 *
	 * @param string $class requested class name.
	 * @since 2.2.0
	 */
	private function autoload($class)
	{
		$name = explode('_', $class);
		if (isset($name[1])) {
			$class_name       = strtolower($name[1]);
			$edp_config_paths = array('views/', 'views/configs/settings/', 'views/configs/generator/');
			foreach ($edp_config_paths as $ta_edp_path) {
				$filename = plugin_dir_path(__FILE__) . '/' . $ta_edp_path . 'class-edp-' . $class_name . '.php';
				if (($filename !== null && file_exists($filename))) {
					require_once $filename;
				}
			}
		}
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Event_Details_Pro_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Event_Details_Pro_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$current_screen        = get_current_screen();
		$the_current_post_type = $current_screen->post_type;
		if ('event_detailer' == $the_current_post_type) {
			wp_enqueue_style('event-detailer-admin', EDP_ADMIN_ASSETS . 'css/event-detailer-pro-admin' . $this->suffix . '.css', array(), $this->version, 'all');
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Event_Detailer_Pro_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Event_Detailer_Pro_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$current_screen        = get_current_screen();
		$the_current_post_type = $current_screen->post_type;
		if ('event_detailer' == $the_current_post_type) {
			wp_enqueue_script('event-detailer-admin', EDP_ADMIN_ASSETS . 'js/event-detailer-pro-admin' . $this->suffix . '.js', array('jquery'), $this->version, false);
		}
	}

	/**
	 * Add event detailer admin columns.
	 *
	 * @since 2.0.0
	 * @return statement
	 */
	public function filter_event_detailer_admin_column()
	{
		$admin_columns['cb']         = '<input type="checkbox" />';
		$admin_columns['title']      = esc_html__('Title', 'event-detailer-pro');
		$admin_columns['applied_on']  = esc_html__('Applied On', 'event-detailer-pro');
		$admin_columns['edp_layout'] = esc_html__('Layout', 'event-detailer-pro');
		$admin_columns['date']       = esc_html__('Date', 'event-detailer-pro');

		return $admin_columns;
	}

	/**
	 * Display admin columns for the event detailer.
	 *
	 * @param mix    $column The columns.
	 * @param string $post_id The post ID.
	 * @return void
	 */
	public function display_event_detailer_admin_fields($column, $post_id)
	{
		$text        = '';
		$value       = '';
		$specifc_val = '';

		$edp_layouts     = get_post_meta($post_id, 'ta_edp_layouts', true);
		$event_detailer_types = isset($edp_layouts['edp_layout_preset']) ? $edp_layouts['edp_layout_preset'] : '';

		switch ($column) {
			case 'applied_on':
				$edp_filter_content = get_post_meta($post_id, 'ta_edp_view_options', true);
				$edp_apply_on = isset($edp_filter_content['edp_apply_on']) ? $edp_filter_content['edp_apply_on'] : '';


				if (!empty($edp_apply_on)) {
					if ($edp_apply_on == 'specific_event') {
						$text  = __('Specific Event', 'event-detailer-pro');
						$value = isset($edp_filter_content['edp_specific_event']) ? $edp_filter_content['edp_specific_event'] : '';
					} elseif ($edp_apply_on == 'specific_cate') {
						$text  = __('Specific Category', 'event-detailer-pro');
						$value = isset($edp_filter_content['edp_specific_cat']) ? $edp_filter_content['edp_specific_cat'] : '';
					} elseif ($edp_apply_on == 'all_event') {
						$text = __('All Event', 'event-detailer-pro');
					}
					if (!empty($value)) {
						$specifc_val = implode(',', $value);
					}
					$set_value = ($text . ':-' . $specifc_val);
					if ($set_value == ':-') {
						echo 'N/A';
					} else {
						echo esc_html($set_value);
					}
				}

				break;
			case 'edp_layout':
				$layout = ucwords(str_replace('_layout', ' ', $event_detailer_types));
				echo esc_html($layout, 'event-detailer-pro');
				break;
		} // end switch.
	}

	/**
	 * If main plugin not installed
	 *
	 * @since 1.0.0
	 * @access publics
	 */
	public function event_detailer_pro_admin_notices() {
		if(function_exists('tribe_get_events')) {
			return ;
		}
		$current_screen        = get_current_screen();
		$the_current_post_type = $current_screen->post_type;
		if('event_detailer' == $the_current_post_type) {
		?>
			<div class="notice is-dismissible">
				<p><strong>Event Detailer Pro</strong> plugin requires installing <a href="<?php echo esc_url(get_admin_url()) . 'plugin-install.php?s=The%2520Events%2520Calendar&tab=search&type=term'; ?>">The Events Calendar</a>
			</div>
		<?php
		}
	}

	/**
	 * If it is the plugins page.
	 *
	 * @since 2.2.0
	 * @access private
	 */
	private function is_plugins_screen()
	{
		return in_array(get_current_screen()->id, ['plugins', 'plugins-network']);
	}
}

/**
 * Event Detailer dashboard capability.
 *
 * @return string
 */
function edp_dashboard_capability()
{
	return apply_filters('edp_dashboard_capability', 'manage_options');
}
