<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://themeatelier.net
 * @since      1.0.0
 *
 * @package    Event_Detailer_Pro
 * @subpackage Event_Detailer_Pro/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Event_Detailer_Pro
 * @subpackage Event_Detailer_Pro/includes
 * @author     ThemeAtelier <info@themeatelier.net>
 */
class Event_Detailer_Pro
{

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Event_Detailer_Pro_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name = EVENT_DETAILER_PRO_BASENAME;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct()
	{
		$this->define_constants();
		$this->load_dependencies();
		$this->define_common_hooks();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		$this->set_locale();

		add_action('plugins_loaded', array($this, 'edp_plugin_loaded'));
	}

	/**
	 * Define constant if not already set
	 *
	 * @since 2.2.0
	 *
	 * @param string      $name Define constant.
	 * @param string|bool $value Define constant.
	 */
	public function define($name, $value)
	{
		if (!defined($name)) {
			define($name, $value);
		}
	}

	/**
	 * Define constants
	 *
	 * @since 2.2.0
	 */

	public function define_constants()
	{
		$this->define('EDP_VERSION', $this->version);
		$this->define('EDP_PLUGIN_NAME', $this->plugin_name);
		$this->define('EDP_PATH', plugin_dir_path(dirname(__FILE__)));
		$this->define('EDP_TEMPLATE_PATH', plugin_dir_path(dirname(__FILE__)) . 'public/templates/');
		$this->define('EDP_URL', plugin_dir_url(dirname(__FILE__)));
		$this->define('EDP_ASSETS', EDP_URL . 'public/assets/');
		$this->define('EDP_FRAMEWORK_ASSETS', EDP_URL . 'admin/views/ta-framework/assets/');
		$this->define('EDP_ADMIN_ASSETS', EDP_URL . 'admin/assets/');
		$this->define('EVENT_DETAILER_PRO_BASENAME', EVENT_DETAILER_PRO_BASENAME);
	}


	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Event_Detailer_Pro_Loader. Orchestrates the hooks of the plugin.
	 * - Event_Detailer_Pro_i18n. Defines internationalization functionality.
	 * - Event_Detailer_Pro_Admin. Defines all hooks for the admin area.
	 * - Event_Detailer_Pro_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies()
	{

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-event-detailer-pro-loader.php';

		/**
		 * The class responsible for all custom post types of this plugin
		 */
		require_once EDP_PATH . 'includes/class-event-detailer-pro-post-types.php';


		/**
		 * The class responsible for defining metabox config that occur in the admin area.
		 */
		require_once EDP_PATH . 'admin/helpers/class-edp-functions.php';


		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-event-detailer-pro-i18n.php';

		/**
		 * The class responsible for defining ta framework
		 */

		require_once EDP_PATH . 'admin/views/ta-framework/classes/setup.class.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-event-detailer-pro-admin.php';



		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-event-detailer-pro-public.php';

		$this->loader = new Event_Detailer_Pro_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Event_Detailer_Pro_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale()
	{

		$plugin_i18n = new Event_Detailer_Pro_i18n();

		$this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
	}


	/**
	 * Register common hooks.
	 *
	 * @since 1.0.0
	 * @access private
	 */
	private function define_common_hooks()
	{
		$common_hooks = new Event_Detailer_Pro_Post_Type(EDP_PLUGIN_NAME, EDP_VERSION);
		$this->loader->add_action('init', $common_hooks, 'register_event_detailer_post_type', 10);
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks()
	{

		$plugin_admin = new Event_Detailer_Pro_Admin($this->get_plugin_name(), $this->get_version());

		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');

		$this->loader->add_filter('manage_event_detailer_posts_columns', $plugin_admin, 'filter_event_detailer_admin_column');
		$this->loader->add_action('manage_event_detailer_posts_custom_column', $plugin_admin, 'display_event_detailer_admin_fields', 10, 2);


		$this->loader->add_action( 'admin_notices', $plugin_admin, 'event_detailer_pro_admin_notices' );
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks()
	{

		$plugin_public = new Event_Detailer_Pro_Public($this->get_plugin_name(), $this->get_version());

		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run()
	{
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name()
	{
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Event_Detailer_Pro_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader()
	{
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version()
	{
		return $this->version;
	}

	public function edp_plugin_loaded()
	{
		include_once ABSPATH . 'wp-admin/includes/plugin.php';
		if (!class_exists('Tribe__Events__Main') or !defined('Tribe__Events__Main::VERSION')) {
			// Deactivate the plugin
			deactivate_plugins(plugin_basename(__FILE__));

			// Remove links and submenus
			$this->remove_plugin_links_and_submenus();

			return;
		}

		require_once EDP_PATH . 'admin/helpers/class-edp-functions.php';
		require_once EDP_PATH . 'admin/helpers/class-edp-filter.php';
		// if (is_admin()) {

		// 	require_once __DIR__ . '/admin/events-addon-page/events-addon-page.php';
		// 	cool_plugins_events_addon_settings_page('event-detailer-pro', 'cool-plugins-events-addon', '📅 Events Addons For The Events Calendar');
		// 	require_once __DIR__ . '/admin/edp-registration/registration-settings.php';
		// 	require_once __DIR__ . '/admin/edp-registration/init-api.php';
		// 	require_once __DIR__ . '/admin/edp-feedback-notice.php';
		// 	new \EspbpFeedbackNotice\EspbpFeedbackNotice();
		// } else {
		// 	add_action('wp_enqueue_scripts', array($this, 'edp_register_assets'));
		// }
		// if (did_action('elementor/loaded')) {
		// 	require_once EDP_URL . 'edp-widgets/edp-widgets-registered.php';
		// }
	}

	// Function to remove plugin links and submenus
	private function remove_plugin_links_and_submenus()
	{
		// Remove plugin action links
		remove_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'edp_template_settings_page'));

		// Remove submenu created by edp_plugin_redirect()
		remove_submenu_page('edit.php?post_type=epta', 'edp-template-settings');
	}

	/*
        check admin side post type page
         */
	public function edp_get_post_type_page()
	{
		global $post, $typenow, $current_screen;
		if ($post && $post->post_type) {
			return $post->post_type;
		} elseif ($typenow) {
			return $typenow;
		} elseif ($current_screen && $current_screen->post_type) {
			return $current_screen->post_type;
		} elseif (isset($_REQUEST['post_type'])) {
			return sanitize_key($_REQUEST['post_type']);
		} elseif (isset($_REQUEST['post'])) {
			return get_post_type($_REQUEST['post']);
		}
		return null;
	}
}
